[sr-dev] git:master:c67a0eab: rr: different function parameter name to be different than global variable

Daniel-Constantin Mierla miconda at gmail.com
Tue May 5 08:08:15 CEST 2020


Module: kamailio
Branch: master
Commit: c67a0eabea5fd11693bb716782cd581094250f7f
URL: https://github.com/kamailio/kamailio/commit/c67a0eabea5fd11693bb716782cd581094250f7f

Author: Daniel-Constantin Mierla <miconda at gmail.com>
Committer: Daniel-Constantin Mierla <miconda at gmail.com>
Date: 2020-05-05T08:05:07+02:00

rr: different function parameter name to be different than global variable

---

Modified: src/modules/rr/rr_mod.c

---

Diff:  https://github.com/kamailio/kamailio/commit/c67a0eabea5fd11693bb716782cd581094250f7f.diff
Patch: https://github.com/kamailio/kamailio/commit/c67a0eabea5fd11693bb716782cd581094250f7f.patch

---

diff --git a/src/modules/rr/rr_mod.c b/src/modules/rr/rr_mod.c
index 236373a288..71f5fcc18e 100644
--- a/src/modules/rr/rr_mod.c
+++ b/src/modules/rr/rr_mod.c
@@ -303,16 +303,16 @@ static int ki_loose_route_preloaded(sip_msg_t *msg)
 }
 
 /**
  * common wrapper for record_route(msg, params)
  */
-static int ki_record_route_params(sip_msg_t *msg, str *params)
+static int ki_record_route_params(sip_msg_t *msg, str *sparams)
 {
 	if (msg->msg_flags & FL_RR_ADDED) {
 		LM_ERR("Double attempt to record-route\n");
 		return -1;
 	}
 
-	if ( record_route( msg, params )<0 )
+	if ( record_route( msg, sparams )<0 )
 		return -1;
 
 	if(get_route_type()!=BRANCH_ROUTE)
@@ -303,16 +303,16 @@ static int ki_loose_route_preloaded(sip_msg_t *msg)
 
 /**
- * common wrapper for record_route(msg, params)
+ * common wrapper for record_route(msg, sparams)
  */




More information about the sr-dev mailing list